@@ -21,14 +21,31 @@ import gtk, gtk.glade
 import posixpath
 
 from gettext import gettext as _
+from string import Template
 
-from checkbox.test import ALL_STATUS, TestResult
-from checkbox.user_interface import UserInterface
+from checkbox.lib.iterator import NEXT
+
+from checkbox.job import Job, UNINITIATED
+from checkbox.user_interface import (UserInterface,
+    YES_ANSWER, NO_ANSWER, SKIP_ANSWER,
+    ANSWER_TO_STATUS, STATUS_TO_ANSWER)
 
 # Import to register HyperTextView type with gtk
 from checkbox_gtk.hyper_text_view import HyperTextView
 
 
+ANSWER_TO_BUTTON = {
+    YES_ANSWER: "radio_button_yes",
+    NO_ANSWER: "radio_button_no",
+    SKIP_ANSWER: "radio_button_skip"}
+
+BUTTON_TO_STATUS = dict((b, ANSWER_TO_STATUS[a])
+    for a, b in ANSWER_TO_BUTTON.items())
+
+STATUS_TO_BUTTON = dict((s, ANSWER_TO_BUTTON[a])
+    for s, a in STATUS_TO_ANSWER.items())
+
+
 # HACK: Setting and unsetting previous and next buttons to workaround
 #       for gnome bug #56070.
 class GTKHack(object):
@@ -77,8 +94,8 @@ class GTKInterface(UserInterface):
         self._notebook = self._get_widget("notebook_main")
         self._handler_id = None
 
-    def _get_widget(self, widget):
-        return self.widgets.get_widget(widget)
+    def _get_widget(self, name):
+        return self.widgets.get_widget(name)
 
     def _get_radio_button(self, map):
         for radio_button, value in map.items():
@@ -86,6 +103,10 @@ class GTKInterface(UserInterface):
                 return value
         raise Exception, "Failed to map radio_button."
 
+    def _get_label(self, name):
+        widget = self._get_widget(name)
+        return widget.get_label()
+
     def _get_text(self, name):
         widget = self._get_widget(name)
         return widget.get_text()
@@ -155,6 +176,19 @@ class GTKInterface(UserInterface):
         widget = self._get_widget(name)
         widget.set_sensitive(bool(value))
 
+    def _set_button(self, name, value=None):
+        if value is None:
+            state = value
+        else:
+            state = self._get_label(name)
+            if value == "":
+                self._set_sensitive(name, False)
+            else:
+                self._set_sensitive(name, True)
+                self._set_label(name, value)
+
+        return state
+
     def _run_dialog(self, dialog=None):
         def on_dialog_response(dialog, response, self):
             self.direction = response
@@ -167,101 +201,163 @@ class GTKInterface(UserInterface):
         if self.direction == gtk.RESPONSE_DELETE_EVENT:
             raise KeyboardInterrupt
 
-    def do_function(self, function, *args, **kwargs):
+    def show_progress_start(self, message):
         self._set_sensitive("button_previous", False)
         self._set_sensitive("button_next", False)
 
-        result = super(GTKInterface, self).do_function(function,
-            *args, **kwargs)
+        self._set_text("label_wait", message)
+        self._wait.show()
+
+    def show_progress_stop(self):
+        self._wait.hide()
 
         self._set_sensitive("button_previous", True)
         self._set_sensitive("button_next", True)
 
-        return result
-
-    def show_wait(self, message, function, *args, **kwargs):
-        self._set_text("label_wait", message)
-        self._wait.show()
-
-        result = self.do_function(function, *args, **kwargs)
-
-        self._wait.hide()
-        return result
-
-    def show_pulse(self):
+    def show_progress_pulse(self):
         self._get_widget("progressbar_wait").pulse()
         while gtk.events_pending():
             gtk.main_iteration()
 
     @GTKHack
-    def show_intro(self, title, text):
+    def show_text(self, text, previous=None, next=None):
         # Set buttons
-        self._set_sensitive("button_previous", False)
+        previous_state = self._set_button("button_previous", previous)
+        next_state = self._set_button("button_next", next)
+
         self._notebook.set_current_page(0)
 
-        intro = "\n\n".join([title, text])
-        self._set_hyper_text_view("hyper_text_view_intro_text", intro)
+        self._set_hyper_text_view("hyper_text_view_text", text)
 
         self._run_dialog()
 
-        self._set_sensitive("button_previous", True)
+        # Unset buttons
+        self._set_button("button_previous", previous_state)
+        self._set_button("button_next", next_state)
 
     @GTKHack
-    def show_category(self, title, text, category=None):
+    def show_entry(self, text, value, previous=None, next=None):
+        # Set buttons
+        previous_state = self._set_button("button_previous", previous)
+        next_state = self._set_button("button_next", next)
+
+        self._notebook.set_current_page(3)
+
+        if value is not None:
+            self._set_text("entry", value)
+
+        self._set_hyper_text_view("hyper_text_view_entry", text)
+
+        self._run_dialog()
+
+        # Unset buttons
+        self._set_button("button_previous", previous_state)
+        self._set_button("button_next", next_state)
+
+        return self._get_text("entry")
+
+    @GTKHack
+    def show_check(self, text, options=[], default=[]):
         # Set buttons
         self._notebook.set_current_page(1)
 
-        self._set_hyper_text_view("hyper_text_view_category", text)
-        if category:
-            self._set_active("radio_button_%s" % category)
+        # Set options
+        option_table = {}
+        vbox = self._get_widget("vbox_options")
+        for option in options:
+            label = "_%s" % option.capitalize()
+            radio_button = gtk.CheckButton(label)
+            radio_button.show()
+            option_table[option] = radio_button
+            vbox.pack_start(radio_button, False, False, 0)
+            if option in default:
+                radio_button.set_active(True)
+
+        self._set_hyper_text_view("hyper_text_view_options", text)
 
         self._run_dialog()
 
-        return self._get_radio_button({
-            "radio_button_desktop": "desktop",
-            "radio_button_laptop": "laptop",
-            "radio_button_server": "server"})
+        # Get options
+        results = []
+        for option, check_button in option_table.items():
+            if check_button.get_active():
+                results.append(option)
+            vbox.remove(check_button)
+
+        return results
+
+    @GTKHack
+    def show_radio(self, text, options=[], default=None):
+        # Set buttons
+        self._notebook.set_current_page(1)
+
+        # Set options
+        option_group = None
+        option_table = {}
+        vbox = self._get_widget("vbox_options")
+        for option in options:
+            label = "_%s" % option.capitalize()
+            radio_button = gtk.RadioButton(option_group, label)
+            radio_button.show()
+            option_table[option] = radio_button
+            vbox.pack_start(radio_button, False, False, 0)
+            if option_group is None:
+                option_group = radio_button
+            if option == default:
+                radio_button.set_active(True)
+
+        self._set_hyper_text_view("hyper_text_view_options", text)
+
+        self._run_dialog()
+
+        # Get option
+        result = None
+        for option, radio_button in option_table.items():
+            if radio_button.get_active():
+                result = option
+            vbox.remove(radio_button)
+
+        return result
 
     def _run_test(self, test):
         self._set_sensitive("button_test", False)
 
-        message = _("Running test %s...") % test.name
-        result = self.show_wait(message, test.command)
+        message = _("Running test %s...") % test["name"]
+        job = Job(test["command"], test.get("environ"),
+            test.get("timeout"), test.get("user"))
+        (status, data, duration) = self.show_progress(message, job.execute)
 
-        description = self.do_function(test.description, result)
+        description = Template(test["description"]).substitute({
+            "output": data.strip()})
         self._set_hyper_text_view("hyper_text_view_test", description)
 
-        self._set_sensitive("button_test", True)
+        self._set_active(STATUS_TO_BUTTON[status])
         self._set_label("button_test", _("_Test Again"))
+        self._set_sensitive("button_test", True)
 
     @GTKHack
-    def show_test(self, test, result=None):
+    def show_test(self, test):
         self._set_sensitive("button_test", False)
         self._notebook.set_current_page(2)
 
         # Set test description
-        description = self.do_function(test.description, result)
-        self._set_hyper_text_view("hyper_text_view_test", description)
+        if re.search(r"\$output", test["description"]):
+            self._run_test(test)
+        else:
+            self._set_hyper_text_view("hyper_text_view_test",
+                test["description"])
 
         # Set buttons
-        if str(test.command):
+        if "command" in test:
             self._set_sensitive("button_test", True)
-
             button_test = self._get_widget("button_test")
             if self._handler_id:
                 button_test.disconnect(self._handler_id)
             self._handler_id = button_test.connect("clicked",
                 lambda w, t=test: self._run_test(t))
 
-        # Default results
-        answers = ["yes", "no", "skip"]
-        if result:
-            self._set_text_view("text_view_comment", result.data)
-            answer = dict(zip(ALL_STATUS, answers))[result.status]
-            self._set_active("radio_button_%s" % answer)
-        else:
-            self._set_text_view("text_view_comment")
-            self._set_active("radio_button_skip")
+        self._set_text_view("text_view_comment", test.get("data", ""))
+        self._set_active(STATUS_TO_BUTTON[test.get("status", UNINITIATED)])
 
         self._run_dialog()
 
@@ -269,45 +365,36 @@ class GTKInterface(UserInterface):
         self._set_hyper_text_view("hyper_text_view_test")
         self._set_label("button_test", _("_Test"))
 
-        radio_buttons = ["radio_button_%s" % a for a in answers]
-        status = self._get_radio_button(dict(zip(radio_buttons, ALL_STATUS)))
-        data = self._get_text_view("text_view_comment")
-        return TestResult(test, status, data)
+        test["data"] = self._get_text_view("text_view_comment")
+        test["status"] = self._get_radio_button(BUTTON_TO_STATUS)
 
-    @GTKHack
-    def show_exchange(self, authentication, message=None):
-        self._notebook.set_current_page(3)
-
-        if authentication is not None:
-            self._set_text("entry_authentication", authentication)
-
-        if message is not None:
-            self._set_hyper_text_view("hyper_text_view_exchange", message)
-
-        self._run_dialog()
-
-        authentication = self._get_text("entry_authentication")
-
-        return authentication
-
-    @GTKHack
-    def show_final(self, message=None):
-        self._set_label("button_next", _("_Finish"))
-        self._notebook.set_current_page(4)
-
-        if message is not None:
-            self._set_hyper_text_view("hyper_text_view_final", message)
-
-        self._run_dialog()
-
-        self._set_label("button_next", _("Ne_xt"))
-
-    def show_error(self, title, text):
+    def show_info(self, text, options=[], default=None):
         message_dialog = gtk.MessageDialog(parent=self._dialog,
-            type=gtk.MESSAGE_ERROR,
-            buttons=gtk.BUTTONS_CLOSE,
+            type=gtk.MESSAGE_INFO,
+            buttons=gtk.BUTTONS_NONE,
             message_format=text)
         message_dialog.set_modal(True)
-        message_dialog.set_title(title)
+        message_dialog.set_title(_("Info"))
+
+        for index, option in enumerate(options):
+            button = getattr(gtk, "STOCK_%s" % option.upper())
+            message_dialog.add_buttons(button, index)
+
+        self._run_dialog(message_dialog)
+        message_dialog.hide()
+
+        response = self.direction
+        self.direction = NEXT
+        return options[response]
+
+    def show_error(self, text):
+        message_dialog = gtk.MessageDialog(parent=self._dialog,
+            type=gtk.MESSAGE_ERROR,
+            buttons=gtk.BUTTONS_NONE,
+            message_format=text)
+        message_dialog.set_modal(True)
+        message_dialog.set_title(_("Error"))
+        message_dialog.set_default_response(1)
+        message_dialog.add_buttons(gtk.STOCK_CLOSE, NEXT)
         self._run_dialog(message_dialog)
         message_dialog.hide()
