@@ -16,10 +16,13 @@
 # You should have received a copy of the GNU General Public License
 # along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
 #
+from subprocess import Popen, PIPE
+
 from gettext import gettext as _
 
 from checkbox.job import FAIL
 from checkbox.plugin import Plugin
+from checkbox.properties import Path
 from checkbox.reactor import StopAllException
 from checkbox.registry import registry_eval_recursive
 
@@ -129,15 +132,28 @@ class ApportUserInterface(UserInterface):
 
 class ApportPrompt(Plugin):
 
+    # Default configuration filename
+    default_filename = Path(default="/etc/default/apport")
+
     def register(self, manager):
         super(ApportPrompt, self).register(manager)
 
         if isinstance(ApportUserInterface, DummyUserInterface):
             return
 
+        self._enabled = False
+        self._manager.reactor.call_on("gather", self.gather)
         self._manager.reactor.call_on("prompt-test", self.prompt_test, 100)
 
+    def gather(self):
+        value = Popen("unset enabled && . %s && echo ${enabled}" % self.default_filename,
+            shell=True, stdout=PIPE, stderr=PIPE).communicate()[0]
+        self._enabled = value.strip() == "1"
+
     def prompt_test(self, interface, test):
+        if not self._enabled:
+            return
+
         if test["status"] != FAIL:
             return
 
