@@ -16,6 +16,10 @@
 # You should have received a copy of the GNU General Public License
 # along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
 #
+import posixpath
+
+from checkbox.lib.cache import cache
+
 from checkbox.properties import String
 from checkbox.registries.command import CommandRegistry
 
@@ -24,10 +28,20 @@ class DmiRegistry(CommandRegistry):
     """Registry for dmi information."""
 
     # Command to retrieve dmi information.
-    command = String(default="dmidecode")
+    command = String(default="grep -r . /sys/class/dmi/id/ 2>/dev/null || true")
 
-    # User to run dmi command
-    user = String(default="root")
+    @cache
+    def items(self):
+        items = []
+        for line in str(self).split("\n"):
+            if not line:
+                continue
 
+            path, value = line.split(":", 1)
+            key = posixpath.basename(path)
+            items.append((key, value))
+
+        return items
+ 
 
 factory = DmiRegistry
