@@ -18,6 +18,8 @@
 #
 import re
 
+from checkbox.lib.cache import cache
+
 from checkbox.properties import String
 from checkbox.registries.command import CommandRegistry
 
@@ -32,11 +34,13 @@ class DpkgRegistry(CommandRegistry):
     # Command to retrieve dpkg information.
     command = String(default="dpkg --version")
 
+    @cache
     def items(self):
         items = []
         match = re.search(r"([\d\.]+) \((.*)\)", str(self))
-        items.append(("version", match.group(1)))
-        items.append(("architecture", match.group(2)))
+        if match:
+            items.append(("version", match.group(1)))
+            items.append(("architecture", match.group(2)))
 
         return items
 
